<?php
header('Content-Type: application/json');
require_once __DIR__ . '/../config/pasaran_config.php';
date_default_timezone_set('Asia/Jakarta');

$pasaran = $_GET['pasaran'] ?? null;

// Validasi pasaran
if (!array_key_exists($pasaran, $pasaranConfig)) {
	echo json_encode(['error' => 'Pasaran tidak valid']);
	exit;
}

// Helper functions
function generateRandomNumbers($count, $min = 0, $max = 9)
{
	$numbers = [];
	for ($i = 0; $i < $count; $i++) {
		$numbers[] = rand($min, $max);
	}
	return implode(' ', $numbers);
}

function generate4D()
{
	return str_pad(rand(0, 9999), 4, '0', STR_PAD_LEFT);
}
function generate3D()
{
	return str_pad(rand(0, 999), 3, '0', STR_PAD_LEFT);
}
function generate2D()
{
	return str_pad(rand(0, 99), 2, '0', STR_PAD_LEFT);
}

function createResult($pasaran, $date)
{
	$result = [
		'BBFS JITU' => generateRandomNumbers(7, 1, 9),
		'ANGKA MAIN' => generateRandomNumbers(5, 1, 9),
		'4D' => [generate4D(), generate4D(), generate4D(), generate4D()],
		'3D' => array_map('generate3D', array_fill(0, 8, null)),
		'2D' => array_map('generate2D', array_fill(0, 10, null)),
		'2D CADANGAN' => array_map('generate2D', array_fill(0, 3, null)),
		'COLOK BEBAS' => [rand(0, 9), rand(0, 9)],
		'COLOK BEBAS 2D' => array_map('generate2D', array_fill(0, 3, null)),
		'SHIO' => [
			'Tikus',
			'Kerbau',
			'Macan',
			'Kelinci',
			'Naga',
			'Ular',
			'Kuda',
			'Kambing',
			'Monyet',
			'Ayam',
			'Anjing',
			'Babi'
		][rand(0, 11)]
	];
	$result['4D UTAMA'] = $result['4D'][0];

	return [
		'pasaran' => $pasaran,
		'date' => $date,
		'time' => date('H:i:s'),
		'formatted_date' => DateTime::createFromFormat('Y-m-d', $date)->format('d-m-Y'),
		'result' => $result
	];
}

$now = new DateTime();
$today = $now->format('Y-m-d');
$yesterday = (clone $now)->modify('-1 day')->format('Y-m-d');
$tomorrow = (clone $now)->modify('+1 day')->format('Y-m-d');

$results_file = __DIR__ . '/../results.json';
$results = file_exists($results_file) ? json_decode(file_get_contents($results_file), true) : [];

// Check and generate today's result if needed
$todayResultExists = false;
foreach ($results as $result) {
	if ($result['pasaran'] === $pasaran && $result['date'] === $today) {
		$todayResultExists = true;
		break;
	}
}

if (!$todayResultExists) {
	$currentDay = $now->format('l');
	if (in_array($currentDay, $pasaranConfig[$pasaran]['days'])) {
		$openTime = new DateTime($today . ' ' . $pasaranConfig[$pasaran]['open_time']);
		// Generate today's result if it's past opening time OR if it's not yet opening time but should exist
		if ($now >= $openTime) {
			$results[] = createResult($pasaran, $today);
		} else {
			// If before opening time but result doesn't exist yet, generate it anyway
			$results[] = createResult($pasaran, $today);
		}
	}
}

// Check and generate tomorrow's result if needed
$tomorrowDay = (clone $now)->modify('+1 day')->format('l');
if (in_array($tomorrowDay, $pasaranConfig[$pasaran]['days'])) {
	$tomorrowResultExists = false;
	foreach ($results as $result) {
		if ($result['pasaran'] === $pasaran && $result['date'] === $tomorrow) {
			$tomorrowResultExists = true;
			break;
		}
	}

	if (!$tomorrowResultExists) {
		$tomorrowOpenTime = new DateTime($tomorrow . ' ' . $pasaranConfig[$pasaran]['open_time']);
		// Only generate tomorrow's result if it's past today's opening time
		$todayOpenTime = new DateTime($today . ' ' . $pasaranConfig[$pasaran]['open_time']);
		if ($now >= $todayOpenTime) {
			$results[] = createResult($pasaran, $tomorrow);
		}
	}
}

// Check and generate yesterday's result if needed (for completeness)
$yesterdayDay = (clone $now)->modify('-1 day')->format('l');
if (in_array($yesterdayDay, $pasaranConfig[$pasaran]['days'])) {
	$yesterdayResultExists = false;
	foreach ($results as $result) {
		if ($result['pasaran'] === $pasaran && $result['date'] === $yesterday) {
			$yesterdayResultExists = true;
			break;
		}
	}

	if (!$yesterdayResultExists) {
		$results[] = createResult($pasaran, $yesterday);
	}
}

file_put_contents($results_file, json_encode($results, JSON_PRETTY_PRINT));

$last_update_file = __DIR__ . '/../last_update.json';
$last_update = file_exists($last_update_file) ? json_decode(file_get_contents($last_update_file), true) : [];
$last_update[$pasaran] = $now->format('Y-m-d H:i:s');
file_put_contents($last_update_file, json_encode($last_update, JSON_PRETTY_PRINT));

echo json_encode(['status' => 'success', 'generated' => [
	'today' => !$todayResultExists,
	'tomorrow' => !$tomorrowResultExists
]]);
